@@ -27,9 +27,9 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#include <fcntl.h>
 #include <signal.h>
 #include <pwd.h>
+#include <fcntl.h>
 #include <sys/types.h>
 #include <sys/ioctl.h>
 #include <sys/wait.h>
@@ -49,7 +49,6 @@
 
 #include "gst-auth.h"
 #include "gst-tool.h"
-#include "gst-hig-dialog.h"
 
 #define GST_AUTH_RESPONSE_NP 1
 
@@ -61,13 +60,13 @@ gst_auth_display_error_message (GstTool *tool, gchar *primary_text, gchar *secon
 {
 	GtkWidget *error_dialog;
 
-	error_dialog = gst_hig_dialog_new (GTK_WINDOW (tool->main_dialog),
-					   GTK_DIALOG_MODAL,
-					   GST_HIG_MESSAGE_ERROR,
-					   primary_text,
-					   secondary_text,
-					   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
-					   NULL);
+	error_dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
+					       GTK_DIALOG_MODAL,
+					       GTK_MESSAGE_ERROR,
+					       GTK_BUTTONS_CLOSE,
+					       primary_text);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (error_dialog),
+						  secondary_text);
 	gtk_dialog_run (GTK_DIALOG (error_dialog));
 	gtk_widget_destroy (error_dialog);
 }
@@ -119,12 +118,14 @@ gst_auth_wait_child (GstTool *tool)
 }
 
 /* runs a term with su in it */
-void
+static void
 gst_auth_run_term (GstTool *tool, gchar *args[])
 {
 	struct termios t;
+	int p[2];
 
-	tool->backend_pid = forkpty (&tool->backend_master_fd, NULL, NULL, NULL);
+	pipe (p);
+	tool->backend_pid = forkpty (&tool->write_fd, NULL, NULL, NULL);
 
 	if (tool->backend_pid < 0) {
 		g_warning ("could not fork to backend");
@@ -137,46 +138,64 @@ gst_auth_run_term (GstTool *tool, gchar *args[])
 		unsetenv("LANG");
 		unsetenv("LANGUAGE");
 
+		dup2 (p[1], 1);
+		dup2 (p[1], 2);
+		close (p[0]);
+
 		execv (args[0], args);
 		exit (255);
 	} else {
 #ifndef __FreeBSD__
 		/* Linux's su works ok with echo disabling */
-		tcgetattr (tool->backend_master_fd, &t);
+/*		tcgetattr (tool->write_fd, &t);
 		t.c_lflag ^= ECHO;
-		tcsetattr (tool->backend_master_fd, TCSANOW, &t);
+		tcsetattr (tool->write_fd, TCSANOW, &t);
+*/
 #endif
-		fcntl (tool->backend_master_fd, F_SETFL, O_NONBLOCK);
+		close (p[1]);
 
-		tool->timeout_id = g_timeout_add (1000, (GSourceFunc) gst_auth_wait_child, tool);
-		tool->backend_stream = fdopen (tool->backend_master_fd, "a+");
+		tool->read_fd      = p[0];
+		tool->timeout_id   = g_timeout_add (1000, (GSourceFunc) gst_auth_wait_child, tool);
+		tool->read_stream  = fdopen (tool->read_fd, "r");
+		tool->write_stream = fdopen (tool->write_fd, "w");
+		setvbuf (tool->read_stream, NULL, _IONBF, 0);
+		fcntl (tool->read_fd, F_SETFL, 0);
 	}
 }
 
-/* writes the password to the term with su in it */
-void
-gst_auth_write_password (GstTool *tool, gchar *pwd)
+/* it guesses whether we have to type password or not */
+static gint
+gst_auth_get_auth_required (GstTool *tool)
 {
-	gchar *answer = "yes\n";
-	gboolean cont = FALSE;
-	gchar *str;
-	
-	/* read all the su or ssh output and flush the descriptors */
+	const gchar  *answer = "yes\n";
+	gboolean      cont   = FALSE;
+	gchar        *s, *str;
+	gint          ret;
+
 	while (!cont) {
-		str = gst_tool_read_from_backend (tool, "assword:", "/no)?", NULL);
+		s   = gst_tool_read_from_backend (tool, "assword:", "/no)?", "\n", NULL);
+		str = g_ascii_strup (s, -1);
 
 		/* FIXME: hope that someday we can get rid of this ssh output string parsing */
-		if (g_strrstr (g_ascii_strup (str, -1), "AUTHENTICITY") != NULL) {
+		if (g_strrstr (str, "AUTHENTICITY") != NULL) {
 			/* it's the "add to known hosts list" ssh's message, just answer "yes" */
-			gst_tool_write_to_backend (tool, answer);
-		} else if (g_strrstr (g_ascii_strup (str, -1), "PASSWORD") != NULL) {
+			gst_tool_write_to_backend (tool, (gchar *) answer);
+		} else if (g_strrstr (str, "PASSWORD") != NULL) {
+			/* it's asking for the password */
 			cont = TRUE;
+			ret  = GST_AUTH_PASSWORD;
+		} else if (g_strrstr (str, "\n") != NULL) {
+			/* this is the last case to test, it's the CR
+			   used to synchronize communication */
+			cont = TRUE;
+			ret  = GST_AUTH_PASSWORDLESS;
 		}
 
+		g_free (s);
 		g_free (str);
 	}
 
-	gst_tool_write_to_backend (tool, pwd);
+	return ret;
 }
 
 static GladeXML *
@@ -192,7 +211,7 @@ load_glade_common (const gchar *widget)
 	return xml;
 }
 
-gint
+static void
 gst_auth_get_password (gchar **password)
 {
 	GladeXML *xml;
@@ -223,9 +242,7 @@ gst_auth_get_password (gchar **password)
 	g_free (blank);
 
 	gtk_widget_destroy (password_dialog);
-	/* FIXME: I added this because if you click "OK", the dialog
-	 * never goes away.  Is it really needed?
-	 */
+
 	while (gtk_events_pending ())
 		gtk_main_iteration ();
 
@@ -234,19 +251,12 @@ gst_auth_get_password (gchar **password)
 		/* Run privileged with password */
 		if (!*password)
 			*password = g_strdup ("");
-		return GST_AUTH_RUN_AS_ROOT;
-		break;
-	case GST_AUTH_RESPONSE_NP:
-		/* Run unprivileged */
-		return GST_AUTH_RUN_AS_USER;
 		break;
 	default:
 		/* Cancel */
-		return GST_AUTH_CANCEL;
+		exit (0);
 		break;
 	}
-
-	g_assert ("Not reached");
 }
 
 /* this is done because we need to synchronize with the backend */
@@ -269,40 +279,28 @@ gst_auth_do_authentication (GstTool *tool, gchar *args[])
 {
 	gchar *password;
 	gint result;
-
-	gchar buffer[40];
-	gint size;
 	struct termios t;
 
 	gst_auth_run_term (tool, args);
+	result = gst_auth_get_auth_required (tool);
 
-	if ((geteuid () == 0) && (tool->remote_config == FALSE)) {
-		/* only avoid password requesting when the user is already root and works locally */
-		tool->root_access = ROOT_ACCESS_REAL;
-	} else {
-		result = gst_auth_get_password (&password);
+	if (result == GST_AUTH_PASSWORD) {
+		gst_auth_get_password (&password);
+		gst_tool_write_to_backend (tool, password);
 
-		if (result == GST_AUTH_RUN_AS_ROOT) {
-			gst_auth_write_password (tool, password);
-			/* gst_auth_read_output (tool); */
-
-			if (strlen (password) > 0)
-				memset (password, 0, strlen (password));
-			tool->root_access = ROOT_ACCESS_REAL;
-		} else if (result == GST_AUTH_RUN_AS_USER) {
-			tool->root_access = ROOT_ACCESS_NONE;
-		} else {
-			exit (0);
-		}
+		if (strlen (password) > 0)
+			memset (password, 0, strlen (password));
 	}
 
+	tool->root_access = ROOT_ACCESS_REAL;
+
 #ifdef __FreeBSD__
 	/* FreeBSD seems to have weird issues with su and echo disabling */
-	tcgetattr (tool->backend_master_fd, &t);
+/*	tcgetattr (tool->write_fd, &t);
 	t.c_lflag ^= ECHO;
-	tcsetattr (tool->backend_master_fd, TCSANOW, &t);
+	tcsetattr (tool->write_fd, TCSANOW, &t);
+*/
 #endif
-
 }
 
 static void
@@ -315,14 +313,16 @@ gst_auth_save_locale (GString* command) {
 	lc_all      = getenv ("LC_ALL");
 	lang        = getenv ("LANG");
 
+	g_string_append (command, "env ");
+
 	if (lc_all)
-		g_string_append_printf (command, "export LC_ALL=\"%s\" && ", lc_all);
-	else if (lc_messages)
-		g_string_append_printf (command, "export LC_MESSAGES=\"%s\" && ", lc_messages);
-	else if (lang)
-		g_string_append_printf (command, "export LANG=\"%s\" && ", lang);
-	else if (language)
-		g_string_append_printf (command, "export LANGUAGE=\"%s\" && ", language);
+		g_string_append_printf (command, "LC_ALL=\"%s\" ", lc_all);
+	if (lc_messages)
+		g_string_append_printf (command, "LC_MESSAGES=\"%s\" ", lc_messages);
+	if (lang)
+		g_string_append_printf (command, "LANG=\"%s\" ", lang);
+	if (language)
+		g_string_append_printf (command, "LANGUAGE=\"%s\" ", language);
 }
 
 void
