@@ -27,7 +27,6 @@
 #include "gst-dialog.h"
 #include "gst-conf.h"
 #include "gst-marshal.h"
-#include "gst-hig-dialog.h"
 
 #ifdef GST_DEBUG
 /* define to x for debugging output */
@@ -376,11 +375,14 @@ gst_dialog_ask_apply (GstDialog *dialog)
                 GtkWidget *w;
                 gint       res;
 
-		w = gst_hig_dialog_new (GTK_WINDOW (dialog),
-					GTK_DIALOG_MODAL,
-					GST_HIG_MESSAGE_QUESTION,
-					_("There are changes which have not been applied"),
-					_("Apply them now?"),
+		w = gtk_message_dialog_new (GTK_WINDOW (dialog),
+					    GTK_DIALOG_MODAL,
+					    GTK_MESSAGE_QUESTION,
+					    GTK_BUTTONS_NONE,
+					    _("There are changes which have not been applied"));
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (w),
+							  _("Apply them now?"));
+		gtk_dialog_add_buttons (GTK_DIALOG (w),
 					GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					GTK_STOCK_APPLY, GTK_RESPONSE_APPLY,
 					NULL);
@@ -448,6 +450,17 @@ dialog_delete_event_cb (GtkWidget *w, GdkEvent *event, gpointer data)
 	cancel_cb (w, data);
 }
 
+static gboolean
+dialog_key_press_event_cb (GtkWidget *w, GdkEventKey *event, gpointer data)
+{
+	if (event->keyval == GDK_Escape) {
+		cancel_cb (w, data);
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 dialog_connect_signals (GstDialog *dialog, GstDialogSignal *signals, gboolean connect_after)
 {       
@@ -548,7 +561,7 @@ gst_dialog_construct (GstDialog *dialog, GstTool *tool,
 
 	g_signal_connect (G_OBJECT (dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
 	g_signal_connect (G_OBJECT (tool->remote_dialog), "delete_event", G_CALLBACK (dialog_delete_event_cb), dialog);
-
+	g_signal_connect (G_OBJECT (dialog), "key-press-event", G_CALLBACK (dialog_key_press_event_cb), dialog);
 }
 
 GstDialog *
