@@ -35,4 +35,7 @@ enum {
 
 void          share_settings_dialog_run        (const gchar*, gboolean);
 void          share_settings_create_combo      (void);
+
+void          smb_settings_prepare_dialog      (void);
+void          smb_settings_save                (void);
 #endif /* _SHARE_SETTINGS_H */
